@@ -11,7 +11,6 @@ import sys
 from collections import defaultdict, OrderedDict
 from copy import deepcopy
 from functools import wraps
-from importlib import import_module
 
 import jsonschema
 import yaml
@@ -1070,3 +1069,26 @@ def get_swag_path_from_doc_dir(method: any, view_class: any, doc_dir: str, endpo
                 logging.exception(f"{file_path} is not a file")
 
     return file_path
+
+def convert_references_to_openapi3(obj):
+    for key, val in obj.items():
+        if key == '$ref':
+            obj[key] = val.replace('definitions', 'components/schemas')
+
+        if isinstance(val, dict):
+            convert_references_to_openapi3(val)
+
+
+def convert_response_definitions_to_openapi3(response, media_types):
+    if 'schema' in response:
+        convert_references_to_openapi3(response['schema'])
+        if 'content' not in response:
+            response['content'] = {}
+            for media_type in media_types:
+                response['content'][media_type] = {'schema': dict(response['schema'])}
+        del response['schema']
+
+
+def convert_responses_to_openapi3(responses, media_types):
+    for val in responses.values():
+        convert_response_definitions_to_openapi3(val, media_types)
\ No newline at end of file
